[![Pyversions](https://img.shields.io/pypi/pyversions/linkml_model.svg)](https://pypi.python.org/pypi/linkml_model)
![](https://github.com/linkml/linkml-model/workflows/Build/badge.svg)
[![PyPi](https://img.shields.io/pypi/v/linkml_model.svg)](https://pypi.python.org/pypi/linkml_model)

# LinkML Model
Basic model and documentation for the Linked Open Data Modeling Language (LinkML)

# [Model Documentation](https://linkml.github.io/linkml-model/docs)
